@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2021 openpyxl
+# Copyright (c) 2010-2022 openpyxl
 
 """Reader for a single worksheet."""
 from copy import copy
@@ -85,7 +85,8 @@ def _cast_number(value):
 class WorkSheetParser(object):
 
     def __init__(self, src, shared_strings, data_only=False,
-                 epoch=WINDOWS_EPOCH, date_formats=set()):
+                 epoch=WINDOWS_EPOCH, date_formats=set(),
+                 timedelta_formats=set()):
         self.min_row = self.min_col = None
         self.epoch = epoch
         self.source = src
@@ -96,6 +97,7 @@ class WorkSheetParser(object):
         self.row_counter = self.col_counter = 0
         self.tables = TablePartList()
         self.date_formats = date_formats
+        self.timedelta_formats = timedelta_formats
         self.row_dimensions = {}
         self.column_dimensions = {}
         self.number_formats = []
@@ -201,9 +203,11 @@ class WorkSheetParser(object):
                 if style_id in self.date_formats:
                     data_type = 'd'
                     try:
-                        value = from_excel(value, self.epoch)
-                    except ValueError:
-                        msg = """Cell {0} is marked as a date but the serial value {1} is outside the limits for dates. The cell will be treated as an error.""".format(coordinate, value)
+                        value = from_excel(
+                            value, self.epoch, timedelta=style_id in self.timedelta_formats
+                        )
+                    except (OverflowError, ValueError):
+                        msg = f"""Cell {coordinate} is marked as a date but the serial value {value} is outside the limits for dates. The cell will be treated as an error."""
                         warn(msg)
                         data_type = "e"
                         value = "#VALUE!"
@@ -337,7 +341,9 @@ class WorksheetReader(object):
 
     def __init__(self, ws, xml_source, shared_strings, data_only):
         self.ws = ws
-        self.parser = WorkSheetParser(xml_source, shared_strings, data_only, ws.parent.epoch, ws.parent._date_formats)
+        self.parser = WorkSheetParser(xml_source, shared_strings,
+                data_only, ws.parent.epoch, ws.parent._date_formats,
+                ws.parent._timedelta_formats)
         self.tables = []
 
 
